==> haskell-lens-family-core-2.1.0-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-family-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lens-family-core
version:              2.1.0
visibility:           public
id:                   lens-family-core-2.1.0-E2lAjFxxScaCmUozZIjJxS
key:                  lens-family-core-2.1.0-E2lAjFxxScaCmUozZIjJxS
license:              BSD-3-Clause
copyright:
    Copyright (C) 2012,2013,2014,2017,2018,2019 Russell O'\''Connor

maintainer:           Russell O'\''Connor <roconnor@theorem.ca>
author:               Russell O'\''Connor
stability:            experimental
synopsis:             Haskell 2022 Lens Families
description:
    This package provides first class(†) functional references in Van Laarhoven style supporting the following optics:

    * Lenses (view, over)

    * Traversals (toListOf, matching, over)

    * Setters (over)

    * Grates (zipWithOf, under, review)

    * Resetters (under)

    * Adapters (view, review)

    * Grids (toListOf, over / under, review)

    * Prisms (matching, over / under, review)

    * Getters (view)

    * Folders (toListOf)

    * Reviewers (review)

    (†) For optimal first-class support use the @lens-family@ package with rank 2 / rank N polymorphism.
    "Lens.Family.Clone" allows for first-class support of lenses and traversals for those who cannot support rank 2 polymorphism.

category:             Data, Lenses
abi:                  f9eb3cb9637c5b7be805c7f667b098ca
exposed:              True
exposed-modules:
    Lens.Family Lens.Family.Clone Lens.Family.State
    Lens.Family.State.Lazy Lens.Family.State.Strict Lens.Family.Stock
    Lens.Family.Unchecked

hidden-modules:
    Lens.Family.Identical Lens.Family.Phantom Lens.Family.State.Zoom

import-dirs:          /usr/lib/ghc-9.0.1/site-local/lens-family-core-2.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/lens-family-core-2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/lens-family-core-2.1.0
hs-libraries:         HSlens-family-core-2.1.0-E2lAjFxxScaCmUozZIjJxS
depends:              base-4.15.0.0 containers-0.6.4.1 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-lens-family-core/html/lens-family-core.haddock

haddock-html:         /usr/share/doc/haskell-lens-family-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lens-family-core-2.1.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-family-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lens-family-core
version:              2.1.2
visibility:           public
id:                   lens-family-core-2.1.2-JgL24qTIUymKZLaMFOVhTK
key:                  lens-family-core-2.1.2-JgL24qTIUymKZLaMFOVhTK
license:              BSD-3-Clause
copyright:
    Copyright (C) 2012,2013,2014,2017,2018,2019 Russell O'\''Connor

maintainer:           Russell O'\''Connor <roconnor@theorem.ca>
author:               Russell O'\''Connor
stability:            experimental
synopsis:             Haskell 2022 Lens Families
description:
    This package provides first class(†) functional references in Van Laarhoven style supporting the following optics:

    * Lenses (view, over)

    * Traversals (toListOf, matching, over)

    * Setters (over)

    * Grates (zipWithOf, under, review)

    * Resetters (under)

    * Adapters (view, review)

    * Grids (toListOf, over / under, review)

    * Prisms (matching, over / under, review)

    * Getters (view)

    * Folders (toListOf)

    * Reviewers (review)

    (†) For optimal first-class support use the @lens-family@ package with rank 2 / rank N polymorphism.
    "Lens.Family.Clone" allows for first-class support of lenses and traversals for those who cannot support rank 2 polymorphism.

category:             Data, Lenses
abi:                  017d6ad3bdfab5cdc25e92c5cc92312d
exposed:              True
exposed-modules:
    Lens.Family Lens.Family.Clone Lens.Family.State
    Lens.Family.State.Lazy Lens.Family.State.Strict Lens.Family.Stock
    Lens.Family.Unchecked

hidden-modules:
    Lens.Family.Identical Lens.Family.Phantom Lens.Family.State.Zoom

import-dirs:          /usr/lib/ghc-9.0.2/site-local/lens-family-core-2.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/lens-family-core-2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-family-core
hs-libraries:         HSlens-family-core-2.1.2-JgL24qTIUymKZLaMFOVhTK
depends:              base-4.15.1.0 containers-0.6.4.1 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-lens-family-core/html/lens-family-core.haddock

haddock-html:         /usr/share/doc/haskell-lens-family-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
